# Introduction

Welcome to the Polaris documentation!

## What is Polaris?

!!! info "Our mission"

    Polaris is on a mission to bring innovators and practitioners closer together to develop methods that matter.

Polaris is an optimistic community that fundamentally believes in the ability of Machine Learning to radically improve lives by disrupting the drug discovery process. However, we recognize that the absence of standardized, domain-appropriate datasets, guidelines, and tools for method evaluation is limiting its current impact.

Polaris is a Python library designed to interact with the [Polaris Hub](https://www.polarishub.io). Our aim is to build the leading benchmarking platform for drug discovery, promoting the use of high-quality resources and domain-appropriate evaluation protocols. Learn more through our [blog posts](https://polarishub.io/blog).

## Where to next?

---

**:fontawesome-solid-rocket:  Quickstart**

If you are entirely new to Polaris, this is the place to start! Learn about the essential concepts and partake in your first benchmark.

[:material-arrow-right: Let's get started](./quickstart.md)


---

**:fontawesome-solid-graduation-cap:  Tutorials**

Dive deeper into the Polaris code and learn about advanced concepts to create your own benchmarks and datasets. 

[:material-arrow-right: Let's get started](./tutorials/submit_to_benchmark.ipynb)

---

**:fontawesome-solid-code:  API Reference**

This is where you will find the technical documentation of the code itself. Learn the intricate details of how the various methods and classes work.

[:material-arrow-right: Let's get started](./api/dataset.md)

---

**:fontawesome-solid-comments:  Community**

Whether you are a first-time contributor or open-source veteran, we welcome any contribution to Polaris. Learn more about our community initiatives.

[:material-arrow-right: Let's get started](https://discord.gg/vBFd8p6H7u)

---

